@@ -35,7 +35,12 @@ import Data.Attoparsec.Lazy (parse)
 import qualified Data.Attoparsec.Lazy as AT
 import Data.Text (Text)
 import qualified Data.Aeson.Types
+#if MIN_VERSION_aeson(2,0,0)
+import qualified Data.Aeson.KeyMap as Map
+import qualified Data.Aeson.Key as Key
+#else
 import qualified Data.HashMap.Lazy as Map
+#endif
 import Control.Applicative ((<$>), (<*>))
 import Control.Exception (throwIO)
 
@@ -97,6 +102,10 @@ parseProfile (Object m) = do
         <*> return (mapMaybe go (Map.toList profile))
   where
     go ("identifier", _) = Nothing
-    go (k, String v) = Just (k, v)
+    go (k, String v) = Just (
+#if MIN_VERSION_aeson(2,0,0)
+        Key.toText
+#endif
+        k, v)
     go _ = Nothing
 parseProfile _ = mzero
